Dealing with dead time
**********************

Stingray implements a few features to deal with instrumental dead time.
This is particularly useful in missions with long dead time, such as NuSTAR or IXPE.
In this tutorial, we will show the effects of dead time on X-ray observations, and explain how Stingray can help model it and, under some conditions, even correct for it.

.. toctree::
   :maxdepth: 2

   notebooks/Deadtime/Check dead time model in Stingray.ipynb
   notebooks/Deadtime/Check FAD correction in Stingray.ipynb
